@@ -5,11 +5,17 @@ mod filter;
 mod id;
 mod summary;
 
+use std::io::Result;
 use std::io::{BufWriter, Write};
 use std::path::{Path, PathBuf};
 
 use clap::ArgMatches;
 use indexmap::IndexSet;
+use log::LevelFilter;
+use log4rs::append::console::ConsoleAppender;
+use log4rs::append::file::FileAppender;
+use log4rs::config::{Appender, Config, Root};
+use log4rs::encode::pattern::PatternEncoder;
 use rayon::prelude::*;
 
 use crate::cli::concat::ConcatParser;
@@ -24,9 +30,12 @@ use crate::helper::finder::{Files, IDs};
 use crate::helper::types::{DataType, InputFmt, OutputFmt, PartitionFmt};
 use crate::helper::utils;
 
+pub const LOG_FILE: &str = "segul.log";
+
 pub fn parse_cli(version: &str) {
     let args = args::get_args(version);
-    utils::print_welcome_text(&version);
+    setup_logger().expect("Failed setting up a log file.");
+    utils::print_welcome_text(version);
     match args.subcommand() {
         ("convert", Some(convert_matches)) => ConvertParser::new(convert_matches).convert(),
         ("concat", Some(concat_matches)) => ConcatParser::new(concat_matches).concat(),
@@ -37,6 +46,35 @@ pub fn parse_cli(version: &str) {
     }
 }
 
+fn setup_logger() -> Result<()> {
+    let log_dir = std::env::current_dir()?;
+    let target = log_dir.join(LOG_FILE);
+    let tofile = FileAppender::builder()
+        .encoder(Box::new(PatternEncoder::new(
+            "{d(%Y-%m-%d %H:%M:%S %Z)} - {l} - {m}\n",
+        )))
+        .build(target)?;
+
+    let stdout = ConsoleAppender::builder()
+        .encoder(Box::new(PatternEncoder::new("{m}\n")))
+        .build();
+
+    let config = Config::builder()
+        .appender(Appender::builder().build("stdout", Box::new(stdout)))
+        .appender(Appender::builder().build("logfile", Box::new(tofile)))
+        .build(
+            Root::builder()
+                .appender("stdout")
+                .appender("logfile")
+                .build(LevelFilter::Info),
+        )
+        .expect("Failed building log configuration");
+
+    log4rs::init_config(config).expect("Cannot initiate log configuration");
+
+    Ok(())
+}
+
 enum InputType {
     File,
     Dir,
